# 58. Детерминированный хаос, бифуркация, странные аттракторы.

Детерминированный хаос:

Примечание: Детерминированность (или определенность) - подразумевается, что в алгоритме определен каждый шаг, то есть сколько бы раз мы его не повторили, получим один и тот же результат.

Детерминированный хаос - это явление, когда динамическая система, несмотря на определенность начальных условий и детерминированных законов, является сложной, из-за чего кажется хаотичной и проблемной в предсказании поведения.

Характеристики таких систем:

- Чувствительность к начальным условиям (даже малое различие условий приводит к иному поведению системы);
- Топологическое смешивание - перемешивание одной области с другой в системе со временем;
- Тонкости определения - хаос определяется несколькими факторами, поэтому даже если кажется, что он есть, то не факт, что это так (например чувствительность к условиям не равно хаос).

Бифуркация:

В широком смысле: Бифуркация — это качественное изменение поведения динамической системы при бесконечно малом изменении её параметров, когда ее параметры проходят через некоторые бифуркационные (критические) значения. Эти значения еще называют точками бифуркации.

В узком смысле: Бифуркация - это раздвоение.

Простыми словами, бифуркация - это моменты, когда поведение системы резко меняется. Двойной маятник неплохо это отображает: сначала вся тысяча маятников (видео со слайда 566) двигается одинаково, а потом происходит абсолютно разное движение.

Бифуркационная диаграмма - представление любого характеристического свойства решения как функции критического параметра.

Пример:

Бифуркация подразделяется на:

- Суперкритичскую (или нормальную, надкритическую) - это когда изменение системы происходит без скачка;
- Субкритическую (или обратную) - это когда, наборот, со скачком.

Сценарий - последовательность бифуркаций, качественно меняющих свойства системы.

Странные аттракторы:

Аттрактор (или точка притяжения) - точка бифуркации, из которой все исходящие решения устойчивы (по сути - рисунок выше).

Странный аттрактор — это притягивающее множество целых неустойчивых траекторий в фазовом пространстве динамической системы. Данные аттракторы выглядят как сложные фрактальные узоры. Примеры: аттрактор Лоренца (слайды 580-581), аттрактор Рёсслера (слайд 582).